@@ -22,6 +22,7 @@ from .scripts.add_edges_to_genes import add_edges_to_genes
 from .scripts.merge_results import merge_results
 from .scripts.normalize_nodes import normalize_nodes
 from .scripts.check_result_size import check_result_size
+from .license import license
 
 
 def new_task(
@@ -46,9 +47,12 @@ def new_task(
     """
 
     extended_genes = map_nodes_to_internal_ids(seeds, parameters)
-    internal_ids = [n["netexId"] for n in extended_genes if "netexId" in n]
-    normalized_params = normalize_task_parameter(parameters, internal_ids)
 
+    if 'identifier' not in parameters:
+        parameters['identifier'] = 'symbol'
+
+    internal_ids = [n[parameters['identifier']][0] for n in extended_genes if n['drugstoneType'] == 'protein']
+    normalized_params = normalize_task_parameter(parameters, internal_ids)
     # static task
     if static:
         dataset = normalized_params["parameters"]["ppi_dataset"]
@@ -73,7 +77,7 @@ def new_task(
     task_params = __create_parameters(task_info)
     if task_info["done"]:
         raw_data = request_task_result(token)
-        normalized = normalize_nodes(raw_data)
+        normalized = normalize_nodes(raw_data, parameters['identifier'])
         task_result = check_result_size(normalized, task_params)
         return Task(result=task_result, raw_data=raw_data, info=task_info, params=task_params)
     return Task(info=task_info, params=task_params)
@@ -83,7 +87,7 @@ def __create_parameters(info: dict) -> dict:
     algor = info["algorithm"]
     param = info["parameters"]
     param["algorithm"] = algor
-    param.pop("inputNetwork")
+    del param["inputNetwork"]
     return param
 
 
